Crate libafl[−][src]
Welcome to LibAFL
Re-exports
pub use fuzzer::*; |
Modules
| bolts | Bolts are no conceptual fuzzing elements, but they keep libafl-based fuzzers together. |
| corpus | Corpuses contain the testcases, either in mem, on disk, or somewhere else. |
| cpu | Architecture agnostic processor features |
| events | Eventmanager manages all events that go to other instances of the fuzzer. |
| executors | Executors take input, and run it in the target. |
| feedbacks | The feedbacks reduce observer state after each run to a single |
| fuzzer | The |
| generators | Generators may generate bytes or, in general, data, for inputs. |
| inputs | Inputs are the actual contents sent to a target for each exeuction. |
| mutators | Mutators mutate input during fuzzing. |
| observers | Observers give insights about runs of a target, such as coverage, timing, stack depth, and more. |
| stages | A |
| state | The fuzzer, and state are the core pieces of every good fuzzer |
| stats | Keep stats, and dispaly them to the user. Usually used in a broker, or main node, of some sort. |
Macros
| create_serde_registry_for_trait | Creates the |
| feedback_and | Variadic macro to create a chain of AndFeedback |
| feedback_not | Variadic macro to create a NotFeedback |
| feedback_or | Variadic macro to create a chain of OrFeedback |
| impl_serdeany | Implement a |
| mark_feature_time | |
| mark_feedback_time | |
| start_timer | |
| tuple_for_each | Iterate over a tuple, executing the given |
| tuple_for_each_mut | Iterate over a tuple, executing the given |
Enums
| Error | Main error struct for AFL |
Attribute Macros
| ctor | Marks a function or static variable as a library/executable constructor. This uses OS-specific linker sections to call a specific function at load time. |