Enum libafl::Error [−][src]
pub enum Error {
}Expand description
Main error struct for AFL
Variants
Serialization error
Tuple Fields of Serialize
0: StringCompression error
File related error
Tuple Fields of File
0: ErrorOptional val was supposed to be set, but isn’t.
Tuple Fields of EmptyOptional
0: StringKey not in Map
Tuple Fields of KeyNotFound
0: StringNo elements in the current item
Tuple Fields of Empty
0: StringEnd of iteration
Tuple Fields of IteratorEnd
0: StringThis is not supported (yet)
Tuple Fields of NotImplemented
0: StringYou’re holding it wrong
Tuple Fields of IllegalState
0: StringThe argument passed to this method or function is not valid
Tuple Fields of IllegalArgument
0: StringForkserver related Error
Tuple Fields of Forkserver
0: StringMOpt related Error
Tuple Fields of MOpt
0: StringShutting down, not really an error.
Something else happened
Tuple Fields of Unknown
0: StringTrait Implementations
Stringify the postcard serializer error
Stringify the json serializer error
Create an AFL Error from io Error
Performs the conversion.
Performs the conversion.
Performs the conversion.